.. _viz:

==============================
Visualizing Spatial Inequality
==============================

.. toctree::
   :maxdepth: 1

   Lorenz Curves and Schutz Line <schutz>
   Pen's Parade and Pengrams <pengram>
